Nextcloud
=========

`Nextcloud <https://nextcloud.com/>`__ is available at
`cloud.example.com`.  The user with administrative rights, the
Nextcloud version and other variables are documented in `this file
<https://lab.enough.community/main/infrastructure/blob/master/playbooks/enough/roles/nextcloud/defaults/main.yml>`__
and can be modified in the
`~/.enough/example.com/inventory/host_vars/cloud-host/nextcloud.yml`
file.
